@@ -68,6 +68,7 @@ color_lookup = {
    "WHITE": (255, 255, 255),
    "YELLOW": (255, 255, 0),
    "ORANGE": (255, 165, 0),
+   "PURPLE": (128, 0, 128)
 }
 
 Color = collections.namedtuple('Color',
@@ -75,7 +76,7 @@ Color = collections.namedtuple('Color',
                                 'GREEN', 'LIGHT_BLUE', 'LIGHT_CYAN',
                                 'LIGHT_GRAY', 'LIGHT_GREEN', 'LIGHT_MAGENTA',
                                 'LIGHT_RED', 'MAGENTA', 'RED', 'WHITE',
-                                'YELLOW', 'ORANGE'])
+                                'YELLOW', 'ORANGE', 'PURPLE'])
 
 colors = Color(
     BLACK=color_lookup['BLACK'],
@@ -94,7 +95,8 @@ colors = Color(
     RED=color_lookup['RED'],
     WHITE=color_lookup['WHITE'],
     YELLOW=color_lookup['YELLOW'],
-    ORANGE=color_lookup['ORANGE'])
+    ORANGE=color_lookup['ORANGE'],
+    PURPLE=color_lookup['PURPLE'])
 
 # Mouse Constants
 mouse_lookup = {
@@ -229,7 +231,9 @@ def _get_rectangle(x1, y1, x2, y2):
         top_left_x = x2
         bottom_right_x = x1
 
-    return pygame.Rect(top_left_x, top_left_y, bottom_right_x - top_left_x + 1,
+    return pygame.Rect(top_left_x,
+                       top_left_y,
+                       bottom_right_x - top_left_x + 1,
                        bottom_right_y - top_left_y + 1)
 
 
@@ -541,12 +545,12 @@ def key_down(which_key):
     # Gets the key codes of the pressed keys
     pressed = pygame.key.get_pressed()
 
-    # Converts the key codes into friendly names ('a' instead of 137)
-    buttons = [_get_key(pygame.key.name(k))
-               for k, v in enumerate(pressed) if v]
-
-    # Checks to see if the desired key is in the array
-    return buttons.count(which_key) > 0
+    # Converts the key specified by the user into
+    # the corresponding pygame key
+    k = pygame.key.key_code(_get_key(which_key))
+        
+    # Returns if the specified key code is legal
+    return pressed[k]
 
 
 def key_released(which_key):
@@ -593,6 +597,12 @@ def wait_for_close():
     while not window_closed():
         update_window()
 
+def save_screenshot(filename):
+    if win is not None:
+        pygame.image.save(win, filename)
+    else:
+        print("Cannot Save Image")
+
 
 def quit():
     global win
@@ -623,3 +633,4 @@ def _load_sound(filename):
     if filename not in sounds.keys():
         sound = pygame.mixer.Sound(filename)
         sounds[filename] = sound
+
